@@ -8,8 +8,6 @@ import pyodbc
 import numpy as np
 import pyodbc
 import missingno as msno
-from nltk.corpus import stopwords
-import nltk
 from sklearn.decomposition import PCA
 from sklearn.feature_extraction.text import TfidfVectorizer
 from sklearn.feature_extraction.text import CountVectorizer
@@ -18,8 +16,6 @@ from sklearn.decomposition import TruncatedSVD
 from data_science_helper import helper_dataframe as hd
 
 import string
-from nltk.stem.snowball import SnowballStemmer
-import nltk 
 from sklearn.metrics import silhouette_score
 from sklearn.manifold import TSNE
 from sklearn.cluster import KMeans
@@ -158,37 +154,45 @@ class CorrTransformer( BaseEstimator, TransformerMixin ):
     
 class CatTransformer( BaseEstimator, TransformerMixin ):
     #Class Constructor 
-    def __init__( self, pp  = "le" , console= False ):
+    def __init__( self, pp  = "le" , cl_list=None, console= False ):
         
         #columns_cat
         self.cat_encoders  = []
         self.encoded_df = []
         self.pp = pp
         self.console = console
+        self.cl_list = cl_list
     
     #Return self nothing else to do here    
     def fit( self, X, y = None ):
-        
-        self.catcolumns = hd.get_cat_columns(X)
+        if self.cl_list is None:
+            self.catcolumns = hd.get_cat_columns(X)
+        else:
+            self.catcolumns = self.cl_list 
 
         for name in self.catcolumns:
-            if(self.pp=="le"):
-                le = LabelEncoder()  
-            elif(self.pp=="lb"):
-                le = LabelBinarizer()  
+            
+            if name in X.columns:
+            
+                if(self.pp=="le"):
+                    le = LabelEncoder()  
+                elif(self.pp=="lb"):
+                    le = LabelBinarizer()  
+                else:
+                    msg = "Error: pp INVALIDO"
+                    raise Exception(msg)
+                    break;
+                if self.console==True:
+                    print("NEW Binarios {}".format(name))
+                if X[name].isna().any():
+                    msg = "ERROR: La columna "+name+" tiene valores MISSING, corregir eso para continuar"
+                    raise Exception(msg)
+                    #print("ERROR: La columna ",name," tiene valores MISSING, corregir eso para continuar")
+                    break
+                le.fit(X[name])
+                self.cat_encoders.append((name, le))
             else:
-                msg = "Error: pp INVALIDO"
-                raise Exception(msg)
-                break;
-            if self.console==True:
-                print("NEW Binarios {}".format(name))
-            if X[name].isna().any():
-                msg = "ERROR: La columna "+name+" tiene valores MISSING, corregir eso para continuar"
-                raise Exception(msg)
-                #print("ERROR: La columna ",name," tiene valores MISSING, corregir eso para continuar")
-                break
-            le.fit(X[name])
-            self.cat_encoders.append((name, le))
+                print(f"no se transformara la columna {name} porque no existe en el dataframe" )
         return self 
     
     #Method that describes what we need this transformer to do
@@ -196,6 +200,7 @@ class CatTransformer( BaseEstimator, TransformerMixin ):
         
         #print(self.cat_encoders)
         for name, encs in self.cat_encoders :
+            
             df_c = encs.transform(X[name])
             
             prefix = str(name) + "_"
