@@ -13,7 +13,7 @@ from sklearn.model_selection import RandomizedSearchCV
 from lightgbm import early_stopping
 from lightgbm import log_evaluation
 import numpy as np
-from sklearn.metrics import f1_score
+from sklearn.metrics import f1_score , precision_score, recall_score
 #import general as g
 #import core_helper.model.general as g
 #import src.Prj_Core.core_helper.model.general as g
@@ -41,6 +41,7 @@ def get_neg_bagging_fraction_params(y_train=None,params=None,log=0):
     if params is None:
         params = get_default_params()
         
+    params['bagging_freq'] = 1
     params['pos_bagging_fraction'] = 1
     params['neg_bagging_fraction'] = alpha
     params['scale_pos_weight'] = (alpha*N_n)/N_p
@@ -85,10 +86,28 @@ def lgb_f1_score(y_hat, data):
     return 'f1', f1_score(y_true, y_hat), True
 
 
+def lgb_precision_score(y_hat, data):
+    y_true = data.get_label()
+    y_hat = np.round(y_hat) # scikits f1 doesn't like probabilities
+    return 'precision', precision_score(y_true, y_hat), True
+
+def lgb_recall_score(y_hat, data):
+    y_true = data.get_label()
+    y_hat = np.round(y_hat) # scikits f1 doesn't like probabilities
+    return 'recall', recall_score(y_true, y_hat), True
+
+
+
 def get_feval(score):     
     if(score=="f1"):
         feval=lgb_f1_score
         
+    if(score=="precision"):
+        feval=lgb_precision_score
+
+    if(score=="recall"):
+        feval=lgb_recall_score
+        
     return feval
 
 
